Remove duplicate WebTestRenderFrameObserver

We have a RenderFrameObserver attached to the WebFrameTestProxy already
so we can use that for observing. Moves the per-frame mojom over to the
WebFrameTestProxy also.

[email protected]

Bug: 866140
Change-Id: Id2136e96a3ca6f3c73dc65b7d109c51761363973
Reviewed-on: https://chromium-review.googlesource.com/c/chromium/src/+/2163405
Commit-Queue: danakj <[email protected]>
Reviewed-by: Nasko Oskov <[email protected]>
Cr-Commit-Position: refs/heads/master@{#762376}
diff --git a/content/renderer/render_frame_impl.h b/content/renderer/render_frame_impl.h
index caea008d..7fb6fb8 100644
--- a/content/renderer/render_frame_impl.h
+++ b/content/renderer/render_frame_impl.h
@@ -310,10 +310,12 @@
   // Returns the RenderWidget associated with this frame.
   RenderWidget* GetLocalRootRenderWidget();
 
-  // This method must be called after the frame has been added to the frame
-  // tree. It creates all objects that depend on the frame being at its proper
-  // spot.
-  void Initialize();
+  // This method must be called after the WebLocalFrame backing this RenderFrame
+  // has been created and added to the frame tree. It creates all objects that
+  // depend on the frame being at its proper spot.
+  //
+  // Virtual for web tests to inject their own behaviour into the WebLocalFrame.
+  virtual void Initialize();
 
   // Notifications from RenderWidget.
   void WasHidden();